%% Celkov hodnocen variant z mnoiny upsilon
function matice_hodnoceni = finalni_hodnoceni(sdruzena_Hik,l,upsilon,pocet_variant)

% sdruzena_Hik ... velk sdruen matice hodnocen variant dle expert se 4
% sloupci, v kadm je jedno z vznamnch hodnot urujcch lichobnkov
% fuzzy slo

% usilon = upsilon* ... dkov vektor s indexy variant
%   - nap. uspilon* = {x1,x5,x7} -> upsilon = [1,5,7]
%   - poet variant v upsilon* x 4

% l ... zpsobilost expert - dkov vektor
%   - monosti: "em", "vm", "m", "p", "v", "vv", "ev"

% matice_hodnoceni ... celkov hodnocen variant z upsilon*

pocet_variant_v_upsilon = size(upsilon,2); % poet variant v upsilon*
pocet_expertu = size(l,2);
matice_hodnoceni = zeros(pocet_variant_v_upsilon,4);

% v tto agregaci se vhy expert nebudou mnit jako pedtm v prvn
% agregaci -> hranice lb pro zpsobilosti expert do fce fmincon nen teba
% potat v kadm kroku algoritmu

% vznamy jazykovch term
em = [0,0,0.08,0.15];
vm = [0.08,0.15,0.23,0.31];
m = [0.23,0.31,0.38,0.46];
p = [0.38,0.46,0.54,0.62];
v = [0.54,0.62,0.69,0.77];
vv = [0.69,0.77,0.85,0.92];
ev = [0.85,0.92,1,1];

% poten vektory:
lb_levy0 = zeros(pocet_expertu,1); % vektor levch krajnch hodnot alfa-ez pro alfa=0 
lb_levy1 = zeros(pocet_expertu,1); % vektor levch krajnch hodnot alfa-ez pro alfa=1 
lb_pravy1 = zeros(pocet_expertu,1); % vektor pravch krajnch hodnot alfa-ez pro alfa=1 
lb_pravy0 = zeros(pocet_expertu,1); % vektor pravch krajnch hodnot alfa-ez pro alfa=0 

% vpoet hodnot do vetor krajnch hodnot alfa-ez
for k=1:pocet_expertu
    if l(k) == "em"
        lb_levy0(k) = em(1); lb_levy1(k) = em(2); lb_pravy1(k) = em(3); lb_pravy0(k) = em(4);
    elseif l(k) == "vm"
        lb_levy0(k) = vm(1); lb_levy1(k) = vm(2); lb_pravy1(k) = vm(3); lb_pravy0(k) = vm(4);
    elseif l(k) == "m"
        lb_levy0(k) = m(1); lb_levy1(k) = m(2); lb_pravy1(k) = m(3); lb_pravy0(k) = m(4);
    elseif l(k) == "prum"
        lb_levy0(k) = p(1); lb_levy1(k) = p(2); lb_pravy1(k) = p(3); lb_pravy0(k) = p(4);
    elseif l(k) == "v"
        lb_levy0(k) = v(1); lb_levy1(k) = v(2); lb_pravy1(k) = v(3); lb_pravy0(k) = v(4);
    elseif l(k) == "vv"
        lb_levy0(k) = vv(1); lb_levy1(k) = vv(2); lb_pravy1(k) = vv(3); lb_pravy0(k) = vv(4);
    elseif l(k) == "ev"
        lb_levy0(k) = ev(1); lb_levy1(k) = ev(2); lb_pravy1(k) = ev(3); lb_pravy0(k) = ev(4);
    else
        error('patn zadan vektor zpsobilosti expert l!')
    end
end
%end

podmatice = zeros(pocet_expertu,4);
for u = 1:pocet_variant_v_upsilon
    varianta = upsilon(u);
    
    for k=1:pocet_expertu
        podmatice(k,:)= sdruzena_Hik(varianta,:); % vbr dk hodnocen dan varianty dle expert
        varianta = varianta + pocet_variant;
    end % dostala jsem tedy podmatici hodnocen u-t varianty dle vech expert
    %                                                  _____
    %                                                 /     \
    % vznamn hodnoty                      lev fce /       \ prav fce
    hik_levy0 = podmatice(:,1); % vektor hodnot levch funkc fuzzy sel pro alfa=0 
    hik_levy1 = podmatice(:,2); % vektor hodnot levch funkc fuzzy sel pro alfa=1 
    hik_pravy1 = podmatice(:,3); % vektor hodnot pravch funkc fuzzy sel pro alfa=1 
    hik_pravy0 = podmatice(:,4); % vektor hodnot pravch funkc fuzzy sel pro alfa=0 
    
    
    % MINIMALIZACE A MAXIMALIZACE
    % minimalizovat, alfa = 0
    xa = lb_levy0; % start bod
    a = @(lk)(sum(lk.*hik_levy0))./(sum(lk));
    [~,fval_leva0]=fmincon(a,xa,[],[],[],[],lb_levy0,lb_pravy0);
    x1 = fval_leva0;

    % maximalizovat, alfa = 0
    xb = lb_levy0;
    b = @(lk)-(sum(lk.*hik_pravy0))./(sum(lk));
    [~,fval_prava0]=fmincon(b,xb,[],[],[],[],lb_levy0,lb_pravy0);
    x4 = -fval_prava0;

    % minimalizovat, alfa = 1
    xc = lb_levy1;
    c = @(lk)(sum(lk.*hik_levy1))./(sum(lk));
    [~,fval_leva1]=fmincon(c,xc,[],[],[],[],lb_levy1,lb_pravy1);
    x2 = fval_leva1;

    % maximalizovat, alfa = 1
    xd = lb_levy1;
    d = @(lk)-(sum(lk.*hik_pravy1))./(sum(lk));
    [~,fval_prava1]=fmincon(d,xd,[],[],[],[],lb_levy1,lb_pravy1);
    x3 = -fval_prava1;

    matice_hodnoceni(u,:) = [x1,x2,x3,x4];
end

end